@@ -16,6 +16,7 @@ from svc_infra.api.fastapi.paths.prefix import AUTH_PREFIX, OAUTH_PREFIX, USER_P
 from svc_infra.app.env import CURRENT_ENVIRONMENT, DEV_ENV, LOCAL_ENV
 from svc_infra.db.sql.apikey import bind_apikey_model
 
+from ..docs.scoped import add_prefixed_docs
 from .policy import AuthPolicy, DefaultAuthPolicy
 from .providers import providers_from_settings
 from .settings import get_auth_settings
@@ -114,7 +115,7 @@ def setup_oauth_authentication(
     user_model,
     auth_backend,
     settings_obj,
-    oauth_prefix: str,
+    auth_prefix: str,
     post_login_redirect: str | None,
     provider_account_model=None,
     auth_policy: AuthPolicy,
@@ -138,7 +139,7 @@ def setup_oauth_authentication(
     # Install oauth prefix routers
     install_oauth_routers(
         app,
-        oauth_prefix=oauth_prefix,
+        oauth_prefix=auth_prefix + "/oauth",
         oauth_router_instance=oauth_router_instance,
         include_in_docs=include_in_docs,
     )
@@ -308,9 +309,12 @@ def add_auth(
             user_model=user_model,
             auth_backend=auth_backend,
             settings_obj=settings_obj,
-            oauth_prefix=oauth_prefix,
+            auth_prefix=auth_prefix,
             post_login_redirect=post_login_redirect,
             provider_account_model=provider_account_model,
             auth_policy=policy,
             include_in_docs=include_in_docs,
         )
+
+    add_prefixed_docs(app, prefix=user_prefix, title="Users")
+    add_prefixed_docs(app, prefix=auth_prefix, title="Auth")
