@@ -3,16 +3,17 @@ from __future__ import annotations
 from typing import Any, AsyncIterator, Callable, Tuple
 from uuid import UUID
 
+from fastapi import Depends
 from fastapi_users import FastAPIUsers
 from fastapi_users.authentication import AuthenticationBackend, BearerTransport, JWTStrategy
 from fastapi_users.manager import BaseUserManager, UUIDIDMixin
 
 from svc_infra.api.fastapi.auth.settings import get_auth_settings
-from svc_infra.api.fastapi.deps import Require
 from svc_infra.api.fastapi.dual.dualize import dualize_public, dualize_user
 from svc_infra.api.fastapi.dual.router import DualAPIRouter
 from svc_infra.app.env import CURRENT_ENVIRONMENT, DEV_ENV, LOCAL_ENV
 
+from ...auth.security import auth_login_path
 from ...auth.sender import get_sender
 from .session import SqlSessionDep
 
@@ -80,7 +81,7 @@ def get_fastapi_users(
             # Optional: audit/log, notify, etc. Keep it no-op by default.
             pass
 
-    async def get_user_manager(user_db=Require(get_user_db)):
+    async def get_user_manager(user_db=Depends(get_user_db)):
         yield UserManager(user_db)
 
     def get_jwt_strategy() -> JWTStrategy:
@@ -95,7 +96,7 @@ def get_fastapi_users(
             lifetime = 3600
         return JWTStrategy(secret=secret, lifetime_seconds=lifetime)
 
-    bearer_transport = BearerTransport(tokenUrl=f"{public_auth_prefix}/login")
+    bearer_transport = BearerTransport(tokenUrl=auth_login_path)
     auth_backend = AuthenticationBackend(
         name="jwt", transport=bearer_transport, get_strategy=get_jwt_strategy
     )
@@ -106,7 +107,7 @@ def get_fastapi_users(
         fastapi_users.get_auth_router(auth_backend, requires_verification=True)
     )
     users_router = dualize_user(
-        fastapi_users.get_users_router(user_schema_read, user_schema_create, user_schema_update)
+        fastapi_users.get_users_router(user_schema_read, user_schema_update)
     )
     register_router = dualize_public(
         fastapi_users.get_register_router(user_schema_read, user_schema_create)
